@@ -24,6 +24,7 @@ if typing.TYPE_CHECKING:
     from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
     from ask_smapi_model.v1.skill.account_linking.account_linking_type import AccountLinkingType as AccountLinkingType_bb3d8e2
+    from ask_smapi_model.v1.skill.account_linking.voice_forward_account_linking_status import VoiceForwardAccountLinkingStatus as VoiceForwardAccountLinkingStatus_5cb337ee
     from ask_smapi_model.v1.skill.account_linking.access_token_scheme_type import AccessTokenSchemeType as AccessTokenSchemeType_e9bad6d7
     from ask_smapi_model.v1.skill.account_linking.account_linking_platform_authorization_url import AccountLinkingPlatformAuthorizationUrl as AccountLinkingPlatformAuthorizationUrl_2972ebae
 
@@ -53,6 +54,8 @@ class AccountLinkingResponse(object):
     :type redirect_urls: (optional) list[str]
     :param authorization_urls_by_platform: The list of valid authorization urls for allowed platforms to initiate account linking.
     :type authorization_urls_by_platform: (optional) list[ask_smapi_model.v1.skill.account_linking.account_linking_platform_authorization_url.AccountLinkingPlatformAuthorizationUrl]
+    :param voice_forward_account_linking: 
+    :type voice_forward_account_linking: (optional) ask_smapi_model.v1.skill.account_linking.voice_forward_account_linking_status.VoiceForwardAccountLinkingStatus
 
     """
     deserialized_types = {
@@ -65,7 +68,8 @@ class AccountLinkingResponse(object):
         'access_token_scheme': 'ask_smapi_model.v1.skill.account_linking.access_token_scheme_type.AccessTokenSchemeType',
         'default_token_expiration_in_seconds': 'int',
         'redirect_urls': 'list[str]',
-        'authorization_urls_by_platform': 'list[ask_smapi_model.v1.skill.account_linking.account_linking_platform_authorization_url.AccountLinkingPlatformAuthorizationUrl]'
+        'authorization_urls_by_platform': 'list[ask_smapi_model.v1.skill.account_linking.account_linking_platform_authorization_url.AccountLinkingPlatformAuthorizationUrl]',
+        'voice_forward_account_linking': 'ask_smapi_model.v1.skill.account_linking.voice_forward_account_linking_status.VoiceForwardAccountLinkingStatus'
     }  # type: Dict
 
     attribute_map = {
@@ -78,12 +82,13 @@ class AccountLinkingResponse(object):
         'access_token_scheme': 'accessTokenScheme',
         'default_token_expiration_in_seconds': 'defaultTokenExpirationInSeconds',
         'redirect_urls': 'redirectUrls',
-        'authorization_urls_by_platform': 'authorizationUrlsByPlatform'
+        'authorization_urls_by_platform': 'authorizationUrlsByPlatform',
+        'voice_forward_account_linking': 'voiceForwardAccountLinking'
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, object_type=None, authorization_url=None, domains=None, client_id=None, scopes=None, access_token_url=None, access_token_scheme=None, default_token_expiration_in_seconds=None, redirect_urls=None, authorization_urls_by_platform=None):
-        # type: (Optional[AccountLinkingType_bb3d8e2], Optional[str], Optional[List[object]], Optional[str], Optional[List[object]], Optional[str], Optional[AccessTokenSchemeType_e9bad6d7], Optional[int], Optional[List[object]], Optional[List[AccountLinkingPlatformAuthorizationUrl_2972ebae]]) -> None
+    def __init__(self, object_type=None, authorization_url=None, domains=None, client_id=None, scopes=None, access_token_url=None, access_token_scheme=None, default_token_expiration_in_seconds=None, redirect_urls=None, authorization_urls_by_platform=None, voice_forward_account_linking=None):
+        # type: (Optional[AccountLinkingType_bb3d8e2], Optional[str], Optional[List[object]], Optional[str], Optional[List[object]], Optional[str], Optional[AccessTokenSchemeType_e9bad6d7], Optional[int], Optional[List[object]], Optional[List[AccountLinkingPlatformAuthorizationUrl_2972ebae]], Optional[VoiceForwardAccountLinkingStatus_5cb337ee]) -> None
         """The account linking information of a skill.
 
         :param object_type: 
@@ -106,6 +111,8 @@ class AccountLinkingResponse(object):
         :type redirect_urls: (optional) list[str]
         :param authorization_urls_by_platform: The list of valid authorization urls for allowed platforms to initiate account linking.
         :type authorization_urls_by_platform: (optional) list[ask_smapi_model.v1.skill.account_linking.account_linking_platform_authorization_url.AccountLinkingPlatformAuthorizationUrl]
+        :param voice_forward_account_linking: 
+        :type voice_forward_account_linking: (optional) ask_smapi_model.v1.skill.account_linking.voice_forward_account_linking_status.VoiceForwardAccountLinkingStatus
         """
         self.__discriminator_value = None  # type: str
 
@@ -119,6 +126,7 @@ class AccountLinkingResponse(object):
         self.default_token_expiration_in_seconds = default_token_expiration_in_seconds
         self.redirect_urls = redirect_urls
         self.authorization_urls_by_platform = authorization_urls_by_platform
+        self.voice_forward_account_linking = voice_forward_account_linking
 
     def to_dict(self):
         # type: () -> Dict[str, object]
