@@ -27,14 +27,15 @@ if typing.TYPE_CHECKING:
 
 class HostedSkillRuntime(Enum):
     """
-    Hosted skill lambda runtime; Node.js 10.x is deprecated by Hosted Skill service as of April 30, 2021.
+    Hosted skill lambda runtime; Node.js 10.x is deprecated by Hosted Skill service as of July 30, 2021.
 
 
 
-    Allowed enum values: [NODE_10_X, PYTHON_3_7]
+    Allowed enum values: [NODE_10_X, PYTHON_3_7, NODE_12_X]
     """
     NODE_10_X = "NODE_10_X"
     PYTHON_3_7 = "PYTHON_3_7"
+    NODE_12_X = "NODE_12_X"
 
     def to_dict(self):
         # type: () -> Dict[str, Any]
