@@ -17,21 +17,27 @@ from __future__ import absolute_import
 from .connections_payload import ConnectionsPayload
 from .extension_initialization_request import ExtensionInitializationRequest
 from .flash_briefing_update_frequency import FlashBriefingUpdateFrequency
+from .knowledge_apis_enablement_channel import KnowledgeApisEnablementChannel
+from .linked_android_common_intent import LinkedAndroidCommonIntent
 from .skill_manifest_localized_privacy_and_compliance import SkillManifestLocalizedPrivacyAndCompliance
 from .music_feature import MusicFeature
 from .dialog_delegation_strategy import DialogDelegationStrategy
 from .skill_manifest_endpoint import SkillManifestEndpoint
-from .video_web_player_feature import VideoWebPlayerFeature
 from .authorized_client_lwa_application import AuthorizedClientLwaApplication
+from .shopping_kit import ShoppingKit
 from .extension_request import ExtensionRequest
 from .voice_profile_feature import VoiceProfileFeature
+from .ios_app_store_common_scheme_name import IOSAppStoreCommonSchemeName
 from .ssl_certificate_type import SSLCertificateType
+from .currency import Currency
 from .viewport_mode import ViewportMode
 from .skill_manifest_events import SkillManifestEvents
 from .alexa_for_business_interface_request import AlexaForBusinessInterfaceRequest
 from .flash_briefing_content_type import FlashBriefingContentType
+from .tax_information import TaxInformation
 from .skill_manifest_privacy_and_compliance import SkillManifestPrivacyAndCompliance
 from .authorized_client_lwa import AuthorizedClientLwa
+from .free_trial_information import FreeTrialInformation
 from .interface_type import InterfaceType
 from .music_apis import MusicApis
 from .distribution_mode import DistributionMode
@@ -50,20 +56,26 @@ from .skill_manifest_envelope import SkillManifestEnvelope
 from .supported_controls import SupportedControls
 from .app_link_interface import AppLinkInterface
 from .skill_manifest_apis import SkillManifestApis
+from .play_store_common_scheme_name import PlayStoreCommonSchemeName
 from .lambda_endpoint import LambdaEndpoint
 from .viewport_specification import ViewportSpecification
 from .catalog_info import CatalogInfo
 from .music_alias import MusicAlias
 from .video_feature import VideoFeature
 from .music_content_type import MusicContentType
+from .subscription_information import SubscriptionInformation
+from .subscription_payment_frequency import SubscriptionPaymentFrequency
+from .catalog_name import CatalogName
 from .friendly_name import FriendlyName
 from .manifest_gadget_support import ManifestGadgetSupport
 from .source_language_for_locales import SourceLanguageForLocales
 from .dialog_manager import DialogManager
 from .video_fire_tv_catalog_ingestion import VideoFireTvCatalogIngestion
+from .automatic_cloned_locale import AutomaticClonedLocale
 from .distribution_countries import DistributionCountries
 from .skill_manifest_publishing_information import SkillManifestPublishingInformation
 from .gadget_support_requirement import GadgetSupportRequirement
+from .tax_information_category import TaxInformationCategory
 from .video_app_interface import VideoAppInterface
 from .custom_apis import CustomApis
 from .flash_briefing_genre import FlashBriefingGenre
@@ -78,8 +90,10 @@ from .game_engine_interface import GameEngineInterface
 from .dialog_management import DialogManagement
 from .gadget_controller_interface import GadgetControllerInterface
 from .smart_home_protocol import SmartHomeProtocol
+from .lambda_ssl_certificate_type import LambdaSSLCertificateType
 from .skill_manifest_localized_publishing_information import SkillManifestLocalizedPublishingInformation
 from .version import Version
+from .android_custom_intent import AndroidCustomIntent
 from .music_request import MusicRequest
 from .video_apis import VideoApis
 from .lambda_region import LambdaRegion
@@ -88,6 +102,7 @@ from .skill_manifest import SkillManifest
 from .manifest_version import ManifestVersion
 from .flash_briefing_apis import FlashBriefingApis
 from .amazon_conversations_dialog_manager import AMAZONConversationsDialogManager
+from .marketplace_pricing import MarketplacePricing
 from .permission_items import PermissionItems
 from .automatic_distribution import AutomaticDistribution
 from .authorized_client import AuthorizedClient
@@ -95,6 +110,7 @@ from .event_name_type import EventNameType
 from .audio_interface import AudioInterface
 from .smart_home_apis import SmartHomeApis
 from .alexa_for_business_interface_request_name import AlexaForBusinessInterfaceRequestName
+from .custom_product_prompts import CustomProductPrompts
 from .app_link_v2_interface import AppLinkV2Interface
 from .alexa_for_business_apis import AlexaForBusinessApis
 from .video_region import VideoRegion
@@ -104,18 +120,23 @@ from .alexa_presentation_apl_interface import AlexaPresentationAplInterface
 from .display_interface import DisplayInterface
 from .catalog_type import CatalogType
 from .music_content_name import MusicContentName
+from .offer_type import OfferType
 from .localized_name import LocalizedName
+from .paid_skill_information import PaidSkillInformation
 from .authorized_client_lwa_application_android import AuthorizedClientLwaApplicationAndroid
 from .custom_localized_information_dialog_management import CustomLocalizedInformationDialogManagement
 from .display_interface_template_version import DisplayInterfaceTemplateVersion
 from .event_publications import EventPublications
 from .demand_response_apis import DemandResponseApis
 from .custom_localized_information import CustomLocalizedInformation
+from .linked_common_schemes import LinkedCommonSchemes
 from .video_prompt_name_type import VideoPromptNameType
 from .video_prompt_name import VideoPromptName
+from .locales_by_automatic_cloned_locale import LocalesByAutomaticClonedLocale
 from .custom_task import CustomTask
 from .supported_controls_type import SupportedControlsType
 from .localized_music_info import LocalizedMusicInfo
 from .video_catalog_info import VideoCatalogInfo
 from .localized_flash_briefing_info import LocalizedFlashBriefingInfo
+from .android_common_intent_name import AndroidCommonIntentName
 from .alexa_presentation_html_interface import AlexaPresentationHtmlInterface
